@@ -291,10 +291,17 @@ prob_tox_samples.dfcrm_selector <- function(x, tall = FALSE,
 
 #' @export
 #' @importFrom magrittr %>%
-#' @importFrom dplyr mutate select everything
+#' @importFrom dplyr mutate select everything all_of
 summary.dfcrm_selector <- function(object, ...) {
   Dose <- N <- Tox <- EmpiricToxRate <- Skeleton <- NULL
   summary.selector(object) %>%
     mutate(Skeleton = c(NA, object$skeleton)) %>%
-    select(Dose, N, Tox, EmpiricToxRate, Skeleton, everything())
+    select(
+      all_of(Dose),
+      all_of(N),
+      all_of(Tox),
+      all_of(EmpiricToxRate),
+      all_of(Skeleton),
+      everything()
+    )
 }
